@@ -69,8 +69,11 @@ class FacebookCall(object):
         if method == 'GET':
             url += "?" + encoded_params
             request = urllib2.Request(url)
-        else:
+        elif method == 'POST':
             request = urllib2.Request(url, encoded_params)
+        elif method == 'DELETE':
+            request = urllib2.Request(url, encoded_params)
+            request.get_method = lambda: 'DELETE'
 
         try:
             response = urllib2.urlopen(request)
